@@ -638,8 +638,8 @@ class Script(default.Script):
                      pyatspi.ROLE_ROOT_PANE,
                      pyatspi.ROLE_FRAME,
                      pyatspi.ROLE_APPLICATION]
-        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
-            for child in event.source.parent:
+        if self.utilities.hasMatchingHierarchy(newLocusOfFocus, rolesList):
+            for child in newLocusOfFocus.parent:
                 if child.getRole() == pyatspi.ROLE_PAGE_TAB_LIST:
                     for tab in child:
                         eventState = tab.getState()
@@ -909,6 +909,11 @@ class Script(default.Script):
             default.Script.onCaretMoved(self, event)
             return
 
+        try:
+            role = orca_state.locusOfFocus.getRole()
+        except:
+            orca.setLocusOfFocus(event, event.source)
+
         if orca_state.locusOfFocus.getRole() == pyatspi.ROLE_TABLE_CELL:
             default.Script.onCaretMoved(self, event)
             return
